@@ -26,12 +26,12 @@ class Normalizer:
 	def __init__(self):
 		self.rules_file = os.path.join(os.path.dirname(__file__),"normalizer_ml.rules")
 		self.rulesDict = dict()
-		
+
 	def normalize(self, text):
 		self.rulesDict = self.LoadRules()
 		words = text.split(" ")
 		word_count = len(words)
-		result = ""
+		result = []
 		for word in words:
 			word = self.trim(word)
 			word_length = len(word)
@@ -45,31 +45,31 @@ class Normalizer:
 				suffix_pos_itr = suffix_pos_itr+1
 			if(word_stemmed == ""):
 				word_stemmed = word
-			result += word_stemmed
-		return result
+			result.append(word_stemmed)
+		return "  ".join(result)
 
-	def LoadRules(self):	
+	def LoadRules(self):
 		rules_dict = dict()
 		line = []
 		line_number = 0
 		rule_number = 0
 		rules_file = codecs. open(self.rules_file,encoding='utf-8', errors='ignore')
 		while 1:
-			line_number = line_number +1 
+			line_number = line_number +1
    			text = unicode( rules_file.readline())
 			if text == "":
 			      break
-			if text[0] == '#': 
+			if text[0] == '#':
 			      continue  #this is a comment - ignore
-			text = text.split("#")[0]   #remove the comment part of the line     
-			line_number = line_number +1       
+			text = text.split("#")[0]   #remove the comment part of the line
+			line_number = line_number +1
 			line = text.strip()  # remove unwanted space
 			if(line == ""):
-				  continue 
+				  continue
 			if(len(line.split("=")) != 2):
 					print "[Error] Syntax Error in the Rules. Line number: ",  line_number
 				  	print "Line: "+ text
-				  	continue 
+				  	continue
 	 		lhs = line.split("=") [ 0 ]  .strip()
 	 		rhs = line.split("=") [ 1 ]  .strip()
 	 		if(len(rhs)>0):
@@ -81,13 +81,13 @@ class Normalizer:
 	 			if(rhs[0]=='"'):
 	 				rhs=rhs[1:len(rhs)]  # if the string is "quoted"
 	 			if(rhs[len(rhs)-1]=='"'):
-	 				rhs=rhs[0:len(rhs)-1]	 # if the string is "quoted"			
+	 				rhs=rhs[0:len(rhs)-1]	 # if the string is "quoted"
 	 		rule_number=rule_number+1
 			rules_dict[lhs]=rhs
 			#print "[", rule_number ,"] " +lhs + " : " +rhs
 		print "Found ",rule_number, " rules."
 		return rules_dict
-	
+
 	def trim(self,word):
 		punctuations=['~','!','@','#','$','%','^','&','*','(',')','-','+','_','=','{','}','|' ,':',';','<','>','\,','.','?']
 		word=word.strip()
@@ -96,14 +96,14 @@ class Normalizer:
 			if word[index] in punctuations:
 				word=word[0:index]
 			else:
-				break 
-			index=index-1	
+				break
+			index=index-1
 		return word
 	def process(self, form):
 		response = """
 		<h2>Normalizer</h2></hr>
 		<p>Enter the text for normalizing in the below text area.
-		 Language of each  word will be detected. 
+		 Language of each  word will be detected.
 		 You can give the text in any language and even with mixed language
 		</p>
 		<form action="" method="post">
@@ -123,14 +123,14 @@ class Normalizer:
 				response = response+"<tr><td>"+key+"</td><td>"+result_dict[key]+"</td></tr>"
 			response = response+"</table>	"
 		else:
-			response=response % ""	
+			response=response % ""
 		return response
 	def get_module_name(self):
 		return "Normalizer"
 	def get_info(self):
 		return 	"Malayalam Normalizer(Experimental)"
-		
-def getInstance():
-	return Normalizer()	
 
-	
+def getInstance():
+	return Normalizer()
+
+
